@@ -743,11 +743,17 @@ class ExView():
 
         Only relevant for detail views, return the key components before
         the last one.
+        
+        The views, as classified by Sage, may either be header, detail, flat
+        or batch.  Both detail, and headers with composite keys, may be 
+        enumerated.        
 
         :returns: {field: value, field: value...}
         """
         kvs = {}
-        if self.protocol in ["DETAIL", ]:
+        self.log.debug("deriving parent key for {} ({}) {}".format(
+            self.rotoid, self.protocol, self.to_dict()))
+        if self.protocol in ["DETAIL", "HEADER", ]:
             if self.indexes:
                 if len(self.indexes[0]) > 1:
                     for field in self.indexes[0][:-1]:
